Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1672)

Unified Diff: chrome/browser/media/cast_remoting_connector.h

Issue 2382623003: CastRemotingConnector: Fix wrong assumption about MR route filtering. (Closed)
Patch Set: Tweak variable name. Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/media/cast_remoting_connector.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/media/cast_remoting_connector.h
diff --git a/chrome/browser/media/cast_remoting_connector.h b/chrome/browser/media/cast_remoting_connector.h
index c19e6fd628c83a90b68155d054c3a1cffa2fb0cc..939123e6a264ddc021c0052900f4a5b3d423ab16 100644
--- a/chrome/browser/media/cast_remoting_connector.h
+++ b/chrome/browser/media/cast_remoting_connector.h
@@ -101,10 +101,10 @@ class CastRemotingConnector
// while a remoting route is available, and is owned by CastRemotingConnector.
class MessageObserver;
// Main constructor. |route_source_id| is the remoting route source specific
// to one tab (WebContents).
CastRemotingConnector(media_router::MediaRouter* router,
- const media_router::MediaSource::Id& route_source_id);
+ const media_router::MediaSource::Id& media_source_id);
~CastRemotingConnector() final;
@@ -162,6 +162,10 @@ class CastRemotingConnector
const std::vector<media_router::MediaRoute>& routes,
const std::vector<media_router::MediaRoute::Id>& ignored) final;
+ // The MediaSource ID referring to any remoted content managed by this
+ // CastRemotingConnector.
+ const media_router::MediaSource::Id media_source_id_;
+
// Set of registered RemotingBridges, maintained by RegisterBridge() and
// DeregisterBridge(). These pointers are always valid while they are in this
// set.
@@ -101,10 +101,10 @@ class CastRemotingConnector
// while a remoting route is available, and is owned by CastRemotingConnector.
class MessageObserver;
- // Main constructor. |route_source_id| is the remoting route source specific
- // to one tab (WebContents).
+ // Main constructor. |media_source_id| refers to any remoted content managed
+ // by this instance (i.e., any remoted content from one tab/WebContents).
CastRemotingConnector(media_router::MediaRouter* router,
« no previous file with comments | « no previous file | chrome/browser/media/cast_remoting_connector.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698